@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -112,11 +112,11 @@
  */
 #ifndef SCIP_EXPORT
 #if defined(_WIN32)
-#define SCIP_EXPORT __declspec(dllexport)
+#define SCIP_EXPORT __declspec(dllexport)                         /**< mark symbol to be exported in DLL */
 #elif defined(__GNUC__) && __GNUC__ >= 4
-#define SCIP_EXPORT __attribute__((__visibility__("default")))
+#define SCIP_EXPORT __attribute__((__visibility__("default")))    /**< mark symbol to be visible in shared library */
 #else
-#define SCIP_EXPORT
+#define SCIP_EXPORT                                               /**< no symbol export attribute known for current compiler */
 #endif
 #endif
 
@@ -133,7 +133,7 @@
 #define SCIP_VERSION     (100*SCIP_VERSION_MAJOR + 10*SCIP_VERSION_MINOR + SCIP_VERSION_PATCH) /**< SCIP version number (multiplied by 100 to get integer number) */
 #define SCIP_SUBVERSION  SCIP_VERSION_SUB  /**< SCIP sub version number */
 #define SCIP_APIVERSION  SCIP_VERSION_API  /**< SCIP API version number */
-#define SCIP_COPYRIGHT   "Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)"
+#define SCIP_COPYRIGHT   "Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)"
 
 
 /*
