@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -49,9 +49,12 @@
 #include "scip/type_sol.h"
 #include "scip/type_var.h"
 #include "scip/type_tree.h"
+#include "scip/type_retcode.h"
 
 typedef struct SCIP_ExprData  SCIP_EXPRDATA;     /**< expression data, e.g., coefficients */
 typedef struct SCIP_Expr      SCIP_EXPR;         /**< expression */
+typedef struct SYM_ExprData   SYM_EXPRDATA;      /**< (additional) data used to encode an expression,
+                                                  *   which is not encoded as another expression */
 
 /** curvature types */
 typedef enum
@@ -658,6 +661,19 @@ typedef struct SCIP_ExprhdlrData SCIP_EXPRHDLRDATA; /**< expression handler data
    SCIP_INTERVAL* childrenbounds, \
    SCIP_Bool*     infeasible)
 
+/** expression callback to get information for symmetry detection
+ *
+ * The method returns information regarding constants and coefficients used in an expression.
+ *
+ *  \param[in] scip            SCIP main data structure
+ *  \param[in] expr            expression to retrieve information from
+ *  \param[out] exprdata       buffer to store retrieved data
+ */
+#define SCIP_DECL_EXPRGETSYMDATA(x) SCIP_RETCODE x (\
+   SCIP*          scip,                        \
+   SCIP_EXPR*     expr,                        \
+   SYM_EXPRDATA** symdata)
+
 /** @} */  /* expression handler */
 
 
